===========================
Examples
===========================
Tenant Tutorial
-----------------
This app comes with an interactive tutorial to teach you how to use ``django-pg-tenants`` and to demonstrate its capabilities. This example project is available under `examples/tenant_tutorial <https://github.com/vintasoftware/django-pg-tenants/blob/master/examples/tenant_tutorial>`_. You will only need to edit the ``settings.py`` file to configure the ``DATABASES`` variable and then you're ready to run

.. code-block:: bash

    ./manage.py runserver

All other steps will be explained by following the tutorial, just open ``http://127.0.0.1:8000`` on your browser.
